@@ -13,11 +13,65 @@ from .utils import Patterns, alignment, get_text, offset
 @lru_cache(32)
 def get_first_included(doclike: Union[Doc, Span]) -> Token:
     for token in doclike:
-        if not token._.excluded:
+        if token.tag_ != "EXCLUDED":
             return token
     raise IndexError("The provided Span does not include any token")
 
 
+def get_normalized_variant(doclike) -> str:
+    tokens = [t.text + t.whitespace_ for t in doclike if not t._.excluded]
+    variant = "".join(tokens)
+    variant = variant.rstrip(" ")
+    variant = re.sub(r"\s+", " ", variant)
+    return variant
+
+
+def spans_generator(match: re.Match) -> Tuple[int, int]:
+    """
+    Iterates over every group, and then yields the full match
+
+    Parameters
+    ----------
+    match : re.Match
+        A match object
+
+    Yields
+    ------
+    Tuple[int, int]
+        A tuple containing the start and end of the group or match
+    """
+    for idx in range(1, len(match.groups()) + 1):
+        yield match.start(idx), match.end(idx)
+    yield match.start(0), match.end(0)
+
+
+def span_from_match(
+    match: re.Match,
+    span_from_group: bool,
+) -> Tuple[int, int]:
+    """
+    Return the span (as a (start, end) tuple) of the first matching group.
+    If `span_from_group=True`, returns the full match instead.
+
+    Parameters
+    ----------
+    match : re.Match
+        The Match object
+    span_from_group : bool
+        Whether to work on groups or on the full match
+
+    Returns
+    -------
+    Tuple[int, int]
+        A tuple containing the start and end of the group or match
+    """
+    if not span_from_group:
+        start_char, end_char = match.start(), match.end()
+    else:
+        start_char, end_char = next(filter(lambda x: x[0] >= 0, spans_generator(match)))
+    return start_char, end_char
+
+
 def create_span(
     doclike: Union[Doc, Span],
     start_char: int,
@@ -30,7 +84,6 @@ def create_span(
     """
     spaCy only allows strict alignment mode for char_span on Spans.
     This method circumvents this.
-
     Parameters
     ----------
     doclike : Union[Doc, Span]
@@ -45,7 +98,6 @@ def create_span(
         The alignment mode.
     ignore_excluded : bool
         Whether to skip excluded tokens.
-
     Returns
     -------
     span:
@@ -128,8 +180,15 @@ class RegexMatcher(object):
     attr : str
         Default attribute to match on, by default "TEXT".
         Can be overiden in the `add` method.
+    flags : Union[re.RegexFlag, int]
+        Additional flags provided to the `re` module.
+        Can be overiden in the `add` method.
     ignore_excluded : bool
         Whether to skip exclusions
+    span_from_group : bool
+        If set to `False`, will create spans basede on the regex's full match.
+        If set to `True`, will use the first matching capturing group as a span
+        (and fall back to using the full match if no capturing group is matching)
     """
 
     def __init__(
@@ -137,14 +196,26 @@ class RegexMatcher(object):
         alignment_mode: str = "expand",
         attr: str = "TEXT",
         ignore_excluded: bool = False,
+        flags: Union[re.RegexFlag, int] = 0,  # No additional flags
+        span_from_group: bool = False,
     ):
         self.alignment_mode = alignment_mode
         self.regex = []
 
         self.default_attr = attr
 
+        self.flags = flags
+        self.span_from_group = span_from_group
+
         self.ignore_excluded = ignore_excluded
 
+        self.set_extensions()
+
+    @staticmethod
+    def set_extensions():
+        if not Span.has_extension("normalized_variant"):
+            Span.set_extension("normalized_variant", getter=get_normalized_variant)
+
     def build_patterns(self, regex: Patterns):
         """
         Build patterns and adds them for matching.
@@ -162,16 +233,22 @@ class RegexMatcher(object):
             if isinstance(patterns, dict):
                 attr = patterns.get("attr")
                 alignment_mode = patterns.get("alignment_mode")
+                flags = patterns.get("flags")
                 patterns = patterns.get("regex")
             else:
                 attr = None
                 alignment_mode = None
+                flags = None
 
             if isinstance(patterns, str):
                 patterns = [patterns]
 
             self.add(
-                key=key, patterns=patterns, attr=attr, alignment_mode=alignment_mode
+                key=key,
+                patterns=patterns,
+                attr=attr,
+                alignment_mode=alignment_mode,
+                flags=flags,
             )
 
     def add(
@@ -181,6 +258,7 @@ class RegexMatcher(object):
         attr: Optional[str] = None,
         ignore_excluded: Optional[bool] = None,
         alignment_mode: Optional[str] = None,
+        flags: Optional[re.RegexFlag] = None,
     ):
         """
         Add a pattern to the registry.
@@ -209,7 +287,10 @@ class RegexMatcher(object):
         if alignment_mode is None:
             alignment_mode = self.alignment_mode
 
-        patterns = [compile_regex(pattern) for pattern in patterns]
+        if flags is None:
+            flags = self.flags
+
+        patterns = [compile_regex(pattern, flags) for pattern in patterns]
 
         self.regex.append((key, patterns, attr, ignore_excluded, alignment_mode))
 
@@ -263,10 +344,15 @@ class RegexMatcher(object):
                 for match in pattern.finditer(text):
                     logger.trace(f"Matched a regex from {key}: {repr(match.group())}")
 
+                    start_char, end_char = span_from_match(
+                        match=match,
+                        span_from_group=self.span_from_group,
+                    )
+
                     span = create_span(
                         doclike=doclike,
-                        start_char=match.start(),
-                        end_char=match.end(),
+                        start_char=start_char,
+                        end_char=end_char,
                         key=key,
                         attr=attr,
                         alignment_mode=alignment_mode,
