@@ -11,10 +11,11 @@ letter_months = [
     r"(?P<month_08>ao[uû]t)",
     r"(?P<month_09>septembre|sept?\.?)",
     r"(?P<month_10>octobre|oct\.?)",
-    r"(?P<month_11>novembre|nov\.)",
+    r"(?P<month_11>novembre|nov\.?)",
     r"(?P<month_12>d[ée]cembre|d[ée]c\.?)",
 ]
 
+
 letter_month_pattern = make_pattern(letter_months, with_breaks=True)
 
 numeric_month_pattern = r"(?<!\d)(0?[1-9]|1[0-2])(?!\d)"
