@@ -1,3 +1,4 @@
+import re
 from typing import Any, Callable, List, Union
 
 from spacy.language import Language
@@ -12,8 +13,8 @@ DEFAULT_CONFIG = dict(
     score_normalization=patterns.score_normalization_str,
     attr="NORM",
     window=7,
-    verbose=0,
     ignore_excluded=False,
+    flags=0,
 )
 
 
@@ -27,8 +28,8 @@ def create_component(
     score_normalization: Union[str, Callable[[Union[str, None]], Any]],
     attr: str,
     window: int,
-    verbose: int,
     ignore_excluded: bool,
+    flags: Union[re.RegexFlag, int],
 ):
     return Score(
         nlp,
@@ -38,6 +39,6 @@ def create_component(
         score_normalization=score_normalization,
         attr=attr,
         window=window,
-        verbose=verbose,
         ignore_excluded=ignore_excluded,
+        flags=flags,
     )
