@@ -16,5 +16,8 @@ def score_normalization(extracted_score: Union[str, None]):
     If available, returns the integer value of the Charlson score.
     """
     score_range = list(range(0, 30))
-    if (extracted_score is not None) and (int(extracted_score) in score_range):
-        return int(extracted_score)
+    try:
+        if (extracted_score is not None) and (int(extracted_score) in score_range):
+            return int(extracted_score)
+    except ValueError:
+        return None
