@@ -1,4 +1,5 @@
-from typing import Any, Callable, List, Union
+import re
+from typing import Any, Callable, Dict, List, Union
 
 from spacy.language import Language
 
@@ -7,13 +8,12 @@ from edsnlp.utils.deprecation import deprecated_factory
 
 DEFAULT_CONFIG = dict(
     regex=patterns.regex,
-    method_regex=patterns.method_regex,
-    value_regex=patterns.value_regex,
+    after_extract=patterns.after_extract,
     score_normalization=patterns.score_normalization_str,
     attr="NORM",
-    window=20,
-    verbose=0,
+    window=10,
     ignore_excluded=False,
+    flags=re.S,
 )
 
 
@@ -23,23 +23,21 @@ def create_component(
     nlp: Language,
     name: str,
     regex: List[str],
-    method_regex: str,
-    value_regex: str,
+    after_extract: List[Dict[str, str]],
     score_normalization: Union[str, Callable[[Union[str, None]], Any]],
     attr: str,
     window: int,
-    verbose: int,
     ignore_excluded: bool,
+    flags: Union[re.RegexFlag, int],
 ):
     return Sofa(
         nlp,
         score_name=name,
         regex=regex,
-        method_regex=method_regex,
-        value_regex=value_regex,
+        after_extract=after_extract,
         score_normalization=score_normalization,
         attr=attr,
         window=window,
-        verbose=verbose,
         ignore_excluded=ignore_excluded,
+        flags=flags,
     )
