@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Union
+from typing import Any, Callable, Dict, List, Optional, Union
 
 import pandas as pd
 import spacy
@@ -6,7 +6,7 @@ from spacy import Language
 from spacy.tokens import Doc, Span
 from tqdm import tqdm
 
-from .helpers import check_spacy_version_for_context
+from .helpers import check_spacy_version_for_context, rgetattr, slugify
 
 nlp = spacy.blank("eds")
 
@@ -52,7 +52,7 @@ def _df_to_spacy(
         note_text = context_values.note_text
         doc = nlp.make_doc(note_text)
         for col in context:
-            doc._.set(col, getattr(context_values, col))
+            doc._.set(slugify(col), rgetattr(context_values, col))
         return doc
 
     yield from map(
@@ -72,7 +72,8 @@ def _pipe_generator(
     note: pd.DataFrame,
     nlp: Language,
     context: List[str] = [],
-    additional_spans: Union[List[str], str] = "discarded",
+    results_extractor: Optional[Callable[[Doc], List[Dict[str, Any]]]] = None,
+    additional_spans: Union[List[str], str] = [],
     extensions: ExtensionSchema = [],
     batch_size: int = 50,
     progress_bar: bool = True,
@@ -80,6 +81,7 @@ def _pipe_generator(
 
     if type(extensions) == str:
         extensions = [extensions]
+
     elif type(extensions) == dict:
         extensions = list(extensions.keys())
 
@@ -98,11 +100,15 @@ def _pipe_generator(
 
     for doc in tqdm(pipeline, total=n_docs, disable=not progress_bar):
 
-        yield _full_schema(
-            doc,
-            additional_spans=additional_spans,
-            extensions=extensions,
-        )
+        if results_extractor:
+            yield results_extractor(doc)
+
+        else:
+            yield _full_schema(
+                doc,
+                additional_spans=additional_spans,
+                extensions=extensions,
+            )
 
 
 def _single_schema(
@@ -118,7 +124,7 @@ def _single_schema(
         "span_type": span_type,
         "start": ent.start_char,
         "end": ent.end_char,
-        **{extension: getattr(ent._, extension) for extension in extensions},
+        **{slugify(extension): rgetattr(ent._, extension) for extension in extensions},
     }
 
 
@@ -175,7 +181,8 @@ def pipe(
     note: pd.DataFrame,
     nlp: Language,
     context: List[str] = [],
-    additional_spans: Union[List[str], str] = "discarded",
+    results_extractor: Optional[Callable[[Doc], List[Dict[str, Any]]]] = None,
+    additional_spans: Union[List[str], str] = [],
     extensions: Union[List[str], str] = [],
     batch_size: int = 1000,
     progress_bar: bool = True,
@@ -219,6 +226,7 @@ def pipe(
                 note=note,
                 nlp=nlp,
                 context=context,
+                results_extractor=results_extractor,
                 additional_spans=additional_spans,
                 extensions=extensions,
                 batch_size=batch_size,
